/***********************************************************************************
Note to User: The purpose of this program is to provide sample SAS code for running
weighted frequencies and means for the FMLA 2018 Worksite Survey, as well as for 
testing for differences across subgroups, using both worksite weights 
and employee weights.

Before running this program, please update the file path in the libname statement.
The file path in this statement should refer to the location on your computer where 
both the FMLA 2018 Worksite Public Use File dataset (FMLA_2018_Worksite_PUF.sas7bdat) 
and the corresponding formats catalog (fmla_2018_worksite_formats.sas7bcat) are saved.
***********************************************************************************/

libname in "INSERT FILE PATH HERE";

options fmtsearch=(in.fmla_2018_worksite_formats);

/*************************************************************************
Run weighted frequencies and means for FMLA 2018 Worksite Survey 
using worksite weights
*************************************************************************/
/*Run weighted industry frequencies on full sample*/
PROC SURVEYFREQ DATA=in.FMLA_2018_Worksite_PUF VARMETHOD = BRR;
WEIGHT Estab_Wt;
REPWEIGHT BootStrap_Estab_Wt1 - BootStrap_Estab_Wt250;
TABLES Q4_CAT;
RUN; 

/*Run weighted mean percentage of female employees across full sample*/
PROC SURVEYMEANS DATA=in.FMLA_2018_Worksite_PUF VARMETHOD = BRR;
WEIGHT Estab_Wt;
REPWEIGHT BootStrap_Estab_Wt1 - BootStrap_Estab_Wt250;
VAR Q7_PCT;
RUN; 

/*Run weighted frequencies of industry by self-reported FMLA coverage status*/
PROC SURVEYFREQ DATA=in.FMLA_2018_Worksite_PUF VARMETHOD = BRR;
WEIGHT Estab_Wt;
REPWEIGHT BootStrap_Estab_Wt1 - BootStrap_Estab_Wt250;
TABLES Q4_CAT * COVERED_SELF_REPORTED;
RUN; 

/*Run mean percentage of female employees by self-reported FMLA coverage status*/
PROC SURVEYMEANS DATA=in.FMLA_2018_Worksite_PUF VARMETHOD = BRR;
DOMAIN COVERED_SELF_REPORTED; 
WEIGHT Estab_Wt;
REPWEIGHT BootStrap_Estab_Wt1 - BootStrap_Estab_Wt250;
VAR Q7_PCT;
RUN; 

/*Test whether mean percentage of female employees differs by self-reported FMLA coverage status*/
PROC SURVEYREG DATA = in.FMLA_2018_Worksite_PUF  VARMETHOD = BRR;
CLASS COVERED_SELF_REPORTED;
WEIGHT Estab_Wt;
REPWEIGHTS BootStrap_Estab_Wt1 - BootStrap_Estab_Wt250;
MODEL Q7_PCT = COVERED_SELF_REPORTED;
LSMEANS COVERED_SELF_REPORTED/DIFF;
RUN;

/*************************************************************************
Run weighted frequencies and means for FMLA 2018 Worksite Survey 
using employee weights
*************************************************************************/

/*Run weighted industry frequencies on full sample*/
PROC SURVEYFREQ DATA=in.FMLA_2018_Worksite_PUF VARMETHOD = BRR;
WEIGHT Emp_Wt;
REPWEIGHT BootStrap_Emp_Wt1- BootStrap_Emp_Wt250;
TABLES Q4_CAT;
RUN; 

/*Run weighted mean percentage of female employees across full sample*/
PROC SURVEYMEANS DATA=in.FMLA_2018_Worksite_PUF VARMETHOD = BRR;
WEIGHT Emp_Wt;
REPWEIGHT BootStrap_Emp_Wt1 - BootStrap_Emp_Wt250;
VAR Q7_PCT;
RUN; 

/*Run weighted frequencies of industry by self-reported FMLA coverage status*/
PROC SURVEYFREQ DATA=in.FMLA_2018_Worksite_PUF VARMETHOD = BRR;
WEIGHT Emp_Wt;
REPWEIGHT BootStrap_Emp_Wt1 - BootStrap_Emp_Wt250;
TABLES Q4_CAT * COVERED_SELF_REPORTED;
RUN; 

/*Run weighted mean percentage of female employees by self-reported FMLA coverage status*/
PROC SURVEYMEANS DATA=in.FMLA_2018_Worksite_PUF VARMETHOD = BRR;
DOMAIN COVERED_SELF_REPORTED; 
WEIGHT Emp_Wt;
REPWEIGHT BootStrap_Emp_Wt1 - BootStrap_Emp_Wt250;
VAR Q7_PCT;
RUN; 

/*Test whether mean percentage of female employees differs by self-reported FMLA coverage status*/
PROC SURVEYREG DATA = in.FMLA_2018_Worksite_PUF  VARMETHOD = BRR;
CLASS COVERED_SELF_REPORTED;
WEIGHT Emp_Wt;
REPWEIGHTS BootStrap_Emp_Wt1 - BootStrap_Emp_Wt250;
MODEL Q7_PCT = COVERED_SELF_REPORTED;
LSMEANS COVERED_SELF_REPORTED/DIFF;
RUN;
